@@ -8,7 +8,7 @@ Quality histogram a la fastQC
 #####################################
 # Get a data set example 
 from sequana import sequana_data
-dataset  = sequana_data("test.fastq", "testing")
+dataset  = sequana_data("test.fastq.gz")
 
 
 
