@@ -14,8 +14,9 @@ from multiqc.modules.base_module import BaseMultiqcModule
 from multiqc.plots import linegraph, table, heatmap, bargraph
 logging.captureWarnings(False)
 
-# Initialise the logger
-log = logging.getLogger('multiqc.sequana/coverage')
+import colorlog
+log = colorlog.getLogger(__name__)
+
 
 
 class MultiqcModule(BaseMultiqcModule):
